{% if user.is_authenticated and user.is_staff %}
    <link rel="stylesheet" type="text/css" href="{{ MEDIA_URL }}inplaceeditform/css/style.css" />
<!--
   it needs jquery to work
    <script src="{{ MEDIA_URL }}js/jquery-1.2.6.min.js"></script>
-->
    <script src="/admin/jsi18n/" type="text/javascript"></script>
    <script src="{{ ADMIN_MEDIA_PREFIX }}js/calendar.js" type="text/javascript"></script>
    <script src="{{ ADMIN_MEDIA_PREFIX }}js/core.js" type="text/javascript"></script>
<!--     <script src="{{MEDIA_URL}}inplaceeditform/js/DateTimeShortcuts2.js" type="text/javascript"></script> -->
    <script src="{{ MEDIA_URL }}inplaceeditform/js/jquery.json.js" type="text/javascript"></script>
    <script src="{{ MEDIA_URL }}inplaceeditform/js/inplaceeditform.js" type="text/javascript"></script>
{% endif %}